@@ -7,7 +7,7 @@ import statsmodels.api as sm
 from scipy.stats import chi2_contingency
 from statsmodels.formula.api import ols
 
-# warnings.filterwarnings('ignore')
+warnings.filterwarnings('ignore')
 
 
 class TTTH_Analyzer:
